===============================
segments
===============================

.. image:: https://travis-ci.org/cldf/segments.png?branch=master
        :target: https://travis-ci.org/cldf/segments

.. image:: https://codecov.io/gh/cldf/segments/branch/master/graph/badge.svg
        :target: https://codecov.io/gh/cldf/segments

.. image:: https://pypip.in/d/segments/badge.png
        :target: https://crate.io/packages/segments?version=latest

A Python package implementing tokenization using orthography profiles.


Requirements
------------

- Python >= 2.7 or >= 3.4

License
-------

Apache License Version 2.0
